@@ -1,3 +1,4 @@
+from functools import partial
 import json
 
 import pandas as pd
@@ -205,7 +206,7 @@ class ArrowEngine(Engine):
         if gather_statistics:
             stats = []
             skip_cols = set()  # Columns with min/max = None detected
-            for row_group in row_groups:
+            for ri, row_group in enumerate(row_groups):
                 s = {"num-rows": row_group.num_rows, "columns": []}
                 for i, name in enumerate(names):
                     if name not in skip_cols:
@@ -214,7 +215,9 @@ class ArrowEngine(Engine):
                         if column.statistics:
                             cs_min = column.statistics.min
                             cs_max = column.statistics.max
-                            if None in [cs_min, cs_max]:
+                            if not column.statistics.has_min_max:
+                                cs_min, cs_max = None, None
+                            if None in [cs_min, cs_max] and ri == 0:
                                 skip_cols.add(name)
                                 continue
                             cs_vals = pd.Series([cs_min, cs_max])
@@ -249,7 +252,9 @@ class ArrowEngine(Engine):
         # This is a list of row-group-descriptor dicts, or file-paths
         # if we have a list of files and gather_statistics=False
         if not parts:
-            parts = pieces
+            parts = [
+                (piece.path, piece.row_group, piece.partition_keys) for piece in pieces
+            ]
         parts = [
             {
                 "piece": piece,
@@ -267,30 +272,27 @@ class ArrowEngine(Engine):
         if isinstance(index, list):
             columns += index
         if isinstance(piece, str):
-            # `piece` is a file path
-            # TODO: What to do about partitions?
-            table = pq.read_table(
-                piece,
-                columns=columns,
-                use_pandas_metadata=True,
-                filesystem=fs,
-                use_threads=False,
-                **kwargs.get("read", {}),
+            # `piece` is a file-path string
+            piece = pq.ParquetDatasetPiece(
+                piece, open_file_func=partial(fs.open, mode="rb")
             )
         else:
-            # `piece` is a row-group
-            with fs.open(piece.path, mode="rb") as f:
-                table = piece.read(
-                    columns=columns,
-                    partitions=partitions,
-                    use_pandas_metadata=True,
-                    file=f,
-                    use_threads=False,
-                    **kwargs.get("read", {}),
-                )
-        df = table.to_pandas(
-            categories=categories, use_threads=False, ignore_metadata=True
-        )[list(columns)]
+            # `piece` contains (path, row_group, partition_keys)
+            piece = pq.ParquetDatasetPiece(
+                piece[0],
+                row_group=piece[1],
+                partition_keys=piece[2],
+                open_file_func=partial(fs.open, mode="rb"),
+            )
+        df = piece.read(
+            columns=columns,
+            partitions=partitions,
+            use_pandas_metadata=True,
+            use_threads=False,
+            **kwargs.get("read", {}),
+        ).to_pandas(categories=categories, use_threads=False, ignore_metadata=True)[
+            list(columns)
+        ]
 
         if index:
             df = df.set_index(index)
