@@ -9,9 +9,9 @@ import pytest
 
 import dask
 from dask import compute
-from dask.compatibility import PY2, PY3
 from dask.delayed import delayed, to_task_dask, Delayed
 from dask.utils_test import inc
+from dask.dataframe.utils import assert_eq
 
 try:
     from operator import matmul
@@ -502,18 +502,11 @@ def test_name_consistent_across_instances():
     func = delayed(identity, pure=True)
 
     data = {"x": 1, "y": 25, "z": [1, 2, 3]}
-    if PY2:
-        assert func(data)._key == "identity-6700b857eea9a7d3079762c9a253ffbd"
-    if PY3:
-        assert func(data)._key == "identity-84c5e2194036c17d1d97c4e3a2b90482"
+    assert func(data)._key == "identity-84c5e2194036c17d1d97c4e3a2b90482"
 
     data = {"x": 1, 1: "x"}
     assert func(data)._key == func(data)._key
-
-    if PY2:
-        assert func(1)._key == "identity-91f02358e13dca18cde218a63fee436a"
-    if PY3:
-        assert func(1)._key == "identity-7126728842461bf3d2caecf7b954fa3b"
+    assert func(1)._key == "identity-7126728842461bf3d2caecf7b954fa3b"
 
 
 def test_sensitive_to_partials():
@@ -608,3 +601,17 @@ def test_attribute_of_attribute():
     assert isinstance(x.a, Delayed)
     assert isinstance(x.a.b, Delayed)
     assert isinstance(x.a.b.c, Delayed)
+
+
+def test_check_meta_flag():
+    from pandas import Series
+    from dask.delayed import delayed
+    from dask.dataframe import from_delayed
+
+    a = Series(["a", "b", "a"], dtype="category")
+    b = Series(["a", "c", "a"], dtype="category")
+    da = delayed(lambda x: x)(a)
+    db = delayed(lambda x: x)(b)
+
+    c = from_delayed([da, db], verify_meta=False)
+    assert_eq(c, c)
